slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPGetSplitPreconditionerTerm

Gets the matrices associated with the split preconditioner.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPGetSplitPreconditionerTerm(NEP nep,PetscInt k,Mat *P)

Not collective, though parallel Mats are returned if the NEP is parallel

### Input Parameters

| nep | - the nonlinear eigensolver context
| k | - the index of the requested term (starting in 0)

### Output Parameter

| P | - the matrix of the requested term

### See Also

NEPSetSplitPreconditioner(), NEPGetSplitPreconditionerInfo()

### Level

advanced

### Location

src/nep/interface/nepbasic.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages